<?php

add_filter('gt3/core/builder_support', function($supports){
	$supports[] = 'elementor';

	return $supports;
});

add_filter('gt3/core/cpt/portfolio/archive_portfolio/set_settings', function($set_settings, $query_args){
	return array(
		'cols' => '2',
		'grid_type' => 'native',
		'hover' => 'type6',
		'grid_gap' => '30px',
		'show_category' => 'yes',
		'show_description' => false,
		'show_view_all' => 'yes',
		'load_items' => 6,
		'query' => array(
			'query' => $query_args
		)
	);
}, 10, 3);

add_filter('gt3/elementor/widgets/register', function($widgets){
	$widgets = array(
		'Accordion',
		'Blog',
		'BlogSimple',
		'Button',
		'Countdown',
		'Counter',
		'CustomMeta',
		'Divider',
		'Flipbox',
		'GoogleMap',
		'ImageBox',
		'ImageCarousel',
		'Portfolio',
		'PortfolioCarousel',
		'PriceBox',
		'ProcessBar',
		'Project',
		'Sharing',
		'Tabs',
		'Team',
		'TeamCarousel',
		'TestimonialsLite',
	);
	if (class_exists('RevSlider')) {
		$widgets[] = 'RevolutionSlider';
	}
	if (class_exists('WooCommerce')) {
		$widgets[] = 'ShopList';
	}
	return $widgets;
});

add_action('elementor/element/gt3-core-blog/general_section/before_section_end', function($element,$args){
	/* @var \Elementor\Widget_Base $element */
	$element->update_control('packery_en',array(
		'condition'=>array(
			'show'=>'newer'
		)
	));
	$element->update_control('static_info_block',array(
		'condition'=>array(
			'show'=>'newer'
		)
	));
},20,2);

add_action('elementor/element/gt3-core-tabs/style_section/before_section_end', function($element,$args){
	/* @var \Elementor\Widget_Base $element */
	$element->update_control('tab_padding',array(
		'default'     => array(
			'top' => '19',
			'right' => '30',
			'bottom' => '19',
			'left' => '30',
		)
	));
	$element->update_control('tab_border_radius',array(
		'default'     => array(
			'size' => 0,
			'unit' => 'px',
		),
	));


},20,2);

add_action('elementor/element/gt3-core-processbar/style_section/before_section_end', function($element,$args){
	$element->add_control(
		'heading_color',
		array(
			'label'   => esc_html__('Heading Color','juris'),
			'type'    => Elementor\Controls_Manager::COLOR,
			'selectors'   => array(
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar .gt3_process_item__number,{{WRAPPER}}.elementor-widget-gt3-core-processbar  .gt3_process_item__heading' => 'color: {{VALUE}};',
			),
		)
	);
	$element->add_control(
		'point_color',
		array(
			'label'   => esc_html__('Point Color','juris'),
			'type'    => Elementor\Controls_Manager::COLOR,
			'selectors'   => array(
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar .gt3_process_item__circle_wrapp' => 'color: {{VALUE}};',
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar .gt3_process_item .gt3_process_item__circle_wrapp .gt3_process_item__circle_line_before' => 'background-image: linear-gradient(90deg, transparent 0%, {{VALUE}} 100%);background-color: {{VALUE}};',
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar .gt3_process_item .gt3_process_item__circle_wrapp .gt3_process_item__circle_line_after' => 'background-image: linear-gradient(90deg, {{VALUE}} 0%, transparent 100% );background-color: {{VALUE}};',
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar.vertical_style-2 .gt3_process_item .gt3_process_item__circle_wrapp .gt3_process_item__circle_line_before' => 'background-image: linear-gradient(0deg, {{VALUE}} 0%, transparent 100%);background-color: {{VALUE}};',
				'{{WRAPPER}}.elementor-widget-gt3-core-processbar.vertical_style-2 .gt3_process_item .gt3_process_item__circle_wrapp .gt3_process_item__circle_line_after' => 'background-image: linear-gradient(0deg, transparent 0%, {{VALUE}} 100% );background-color: {{VALUE}};',
			),
		)
	);
},20,2);

// Meta
add_filter( 'gt3/core/render/blog/listing_meta', function ($compile) {
	return '<div class="listing_meta_wrap">'.$compile.'</div>';
});

/* @var array<HTML> $meta*/
add_filter('gt3/core/render/blog/listing_meta_order', function ($meta_default, $meta_all){
	$new_meta = array(
		$meta_all['category'],
		$meta_all['date'],
		$meta_all['author'],
		$meta_all['comments'],
	);

	return $new_meta;
}, 10, 2);

add_filter('gt3/core/render/blogsimple/listing_meta_order', function ($meta_default, $meta_all){
	$new_meta = array(
		$meta_all['category'],
		$meta_all['date'],
	);

	return $new_meta;
}, 10, 2);

// Media height
add_filter( 'gt3/core/render/blog/media_height', function () {
	return '780';
});

// Post comments
add_filter( 'gt3/core/render/blog/post_comments', function () {

	$comments_text = get_comments_number( get_the_ID() ) == 1 ? esc_html__( 'comment', 'juris' ) : esc_html__( 'comments', 'juris' );

	$icon_post_comments = '<span class="post_comments_icon">'.gt3_svg_icons_name('chat').'</span>';

	if ((int)get_comments_number(get_the_ID()) != 0) {
		return '<span class="post_comments"><a href="' . esc_url(get_comments_link()) . '" title="' . esc_attr(get_comments_number(get_the_ID())) . ' ' . $comments_text . '">' . esc_html(get_comments_number(get_the_ID())) . $icon_post_comments . '</a></span>';
	}

});

// Post author
add_filter( 'gt3/core/render/blog/post_author', function () {
	return '<span class="post_author">' . esc_html__('by', 'juris') . ' <a href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author_meta('display_name')) . '</a></span>';
});

// Post bottom Area
add_filter( 'gt3/core/render/blog/listing_btn', function ($listing_btn, $settings) {

	$show_likes = gt3_option('blog_post_likes');
	$show_share = gt3_option('blog_post_share');

	$all_likes = gt3pb_get_option("likes");

	$featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'single-post-thumbnail');

	$btn_compile = '<div class="clear post_clear"></div><div class="gt3_post_footer">';

	if(!empty($settings['post_btn_link'])) {
		$btn_compile .= '<div class="gt3_module_button_list"><a href="'. esc_url(get_permalink()) .'">'. $settings['post_btn_link_title'] .'</a></div>';
	}

	if ($show_share == "1" || $show_likes == "1") {
		$btn_compile .= '<div class="blog_post_info">';

		if (function_exists('gt3_blog_post_sharing')) {
			ob_start();
			gt3_blog_post_sharing($show_share,$featured_image);
			$btn_compile .= ob_get_clean();
		}

		if (function_exists('gt3_blog_post_likes')) {
			ob_start();
			gt3_blog_post_likes($show_likes,$all_likes);
			$btn_compile .= ob_get_clean();
		}

		$btn_compile .= '</div>';
	}

	$btn_compile .= '<div class="clear"></div></div>';

	return $btn_compile;

}, 10, 2);

// BlogBoxed
add_filter( 'gt3/core/render/blogboxed/block_wrap_start', function () {
	return '<div class="gt3blogboxed_block_wrap">';
});

add_filter( 'gt3/core/render/blogboxed/block_wrap_end', function () {
	return '</div>';
});

// Team
add_filter( 'gt3/core/render/team/team_img_prop', function () {
	$img_ratio = '1.2125';
	return $img_ratio;
});

// PortfolioCarousel
add_filter('gt3/core/elementor/widgets/portfoliocarousel/init/image_ration', function ($default, $settings){
	$cols = !empty($settings['items_per_line']) ? $settings['items_per_line'] : '1';
	switch ($cols) {
		case '1':
			return '0.427';
			break;
		case '2':
		case '3':
		case '4':
		case '5':
			return $default;
			break;
		default:
			return $default;
	}
}, 10, 2);

// Price Table Type Controls Added
add_action('elementor/element/gt3-core-pricebox/basic_section/after_section_start', function($element,$args){
	/* @var \Elementor\Widget_Base $element */
	$element->add_control(
		'view_type',
		array(
			'label'       => esc_html__('View Type', 'juris'),
			'type'        => Elementor\Controls_Manager::SELECT,
			'options'     => array(
				'type1' => esc_html__('Type 1', 'juris'),
				'type2' => esc_html__('Type 2', 'juris'),
			),
			'default'     => 'type1',
		)
	);
},20,2);



/**
 * Elementor Project - Responsive Cols
 */
if ( ! function_exists( 'gt3_team_show_fields' ) ) {
	add_action( 'elementor/element/gt3-core-team/general_section/before_section_end', 'gt3_team_show_fields', 10, 2 );
	add_action( 'elementor/element/gt3-core-teamcarousel/general_section/before_section_end', 'gt3_team_show_fields', 10, 2 );
	function gt3_team_show_fields( $element, $args ) {
		/** @var \Elementor\Widget_Base $element */
		$element->add_control(
			'show_fields',
			array(
				'label' => esc_html__('Show Fields', 'juris'),
				'type'  => Elementor\Controls_Manager::SWITCHER,
				'default'   => 'yes'
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'show_social',
				),
			)
		);
	}
}
if ( ! function_exists( 'gt3_team_fields_color' ) ) {
	add_action( 'elementor/element/gt3-core-team/style_section_section/before_section_end', 'gt3_team_fields_color', 10, 2 );
	add_action( 'elementor/element/gt3-core-teamcarousel/style_section_section/before_section_end', 'gt3_team_fields_color', 10, 2 );
	function gt3_team_fields_color( $element, $args ) {
		/** @var \Elementor\Widget_Base $element */
		$element->add_control(
			'fields_color',
			array(
				'label'     => esc_html__( 'Fields color', 'juris' ),
				'type'      => Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .gt3_single_team_info__item' => 'color: {{VALUE}};',
				),
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'desc_color',
				),
			)
		);
		$element->add_control(
			'fields_color_hover',
			array(
				'label'     => esc_html__( 'Fields color', 'juris' ),
				'type'      => Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .item_wrapper:hover .gt3_single_team_info__item' => 'color: {{VALUE}};',
				),
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'desc_color_hover',
				),
			)
		);

		$element->add_control(
			'team_color',
			array(
				'label'     => esc_html__( 'Background color', 'juris' ),
				'type'      => Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .module_team .item-team-member .item_wrapper' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .module_team.type2 .item-team-member .item_wrapper' => 'padding-top: 60px; padding-bottom: 34px;',
					'{{WRAPPER}}.dots_position-inside .item_list ul.slick-dots' => 'bottom: 45px;',
				),
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'icon_color',
				),
			)
		);
		$element->add_control(
			'team_color_hover',
			array(
				'label'     => esc_html__( 'Background hover color', 'juris' ),
				'type'      => Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .module_team .item-team-member .item_wrapper:hover' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .module_team.type2 .item-team-member .item_wrapper' => 'padding-top: 60px; padding-bottom: 34px;',
					'{{WRAPPER}}.dots_position-inside .item_list ul.slick-dots' => 'bottom: 45px;',
				),
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'icon_color_hover',
				),
			)
		);
	}
}


add_action( 'elementor/element/gt3-core-portfolio/section_section/before_section_end', function ( $element, $args ) {
	/* @var \Elementor\Widget_Base $element */
	$element->update_control( 'hover', array(
		'options'     => array(
			'none'  => esc_html__('None', 'juris'),
			'type1' => esc_html__('Type 1', 'juris'),
			'type2' => esc_html__('Type 2', 'juris'),
			'type3' => esc_html__('Type 3', 'juris'),
			'type4' => esc_html__('Type 4', 'juris'),
			'type5' => esc_html__('Type 5', 'juris'),
			'type6' => esc_html__('Type 6', 'juris'),
			'type7' => esc_html__('Type 7', 'juris'),
		),
	) );
}, 20, 2 );

add_action( 'elementor/element/gt3-core-portfolio/section_section/before_section_end', function ( $element, $args ) {
	/* @var \Elementor\Widget_Base $element */
	$element->update_control( 'static_info_block', array(
		'condition' => array(
			'hover!' => 'type7',
		),
	) );
}, 20, 2 );


