<?php

namespace ElementorModal\Widgets;

use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'ElementorModal\Widgets\GT3_Core_Elementor_Widget_TeamCarousel' ) ) {
	class GT3_Core_Elementor_Widget_TeamCarousel extends \ElementorModal\Widgets\GT3_Core_Widget_Base {

		public function get_name() {
			return 'gt3-core-teamcarousel';
		}

		public function get_title() {
			return esc_html__( 'Team Carousel', 'juris' );
		}

		public function get_icon() {
			return 'gt3-core-elementor-icon eicon-person';
		}

		public function get_main_script_depends(){
			return array_merge(
				parent::get_main_script_depends(),
				array( 'gt3-core/slick' )
			);
		}

		public $POST_TYPE = 'team';
		public $TAXONOMY  = 'team_category';

		public $render_index = 1;

		public function get_tax_query_fields() {
			$terms  = get_terms( array(
				'taxonomy'   => $this->POST_TYPE,
				'hide_empty' => true,
			) );
			$return = array();
			if ( is_array( $terms ) && count( $terms ) ) {
				foreach ( $terms as $term ) {
					/* @var \WP_Term $term */
					$return[ $term->term_id ] = $term->name;
				}
			}

			return $return;
		}

		public function get_authors_fields() {
			$users = get_users();

			$return = array();
			foreach ( $users as $user ) {
				$return[ $user->ID ] = $user->display_name;
			}

			return $return;
		}

		function getSlugById( $taxonomy, $ids ) {
			$slugs = array();

			$terms = get_terms( array(
				'taxonomy' => $taxonomy,
				'include'  => $ids,
			) );
			if ( ! is_wp_error( $terms ) ) {
				if ( is_array( $terms ) && count( $terms ) ) {
					foreach ( $terms as $term ) {
						$slugs[] = $term->slug;
					}
				}
			}

			return $slugs;
		}

		function isIds( $ids ) {
			if ( is_array( $ids ) && count( $ids ) ) {
				foreach ( $ids as $id ) {
					if ( ! is_numeric( $id ) ) {
						return false;
					}
				}

				return true;
			}

			return false;
		}

		public function get_taxonomy( $args ) {
			if ( $this->isIds( $args ) ) {
				$args = $this->getSlugById( $this->TAXONOMY, $args );
			}

			$terms  = get_terms( array(
				'taxonomy'   => $this->TAXONOMY,
				'hide_empty' => false,
				'slug'       => $args,
			) );
			$return = array();
			if ( is_array( $terms ) && count( $terms ) ) {
				foreach ( $terms as $term ) {
					/* @var \WP_Term $term */
					$return[ $term->term_id ] = array( 'slug' => $term->slug, 'name' => $term->name );
				}
			}

			return $return;
		}

		public function render_team_item( $posts_per_line, $single_member = false, $grid_gap = '', $link_post = '', $custom_item_height = '', $settings = false ) {
			$id      = get_the_ID();
			$compile = $signature = $post_cats_str = $url_str = $icon_str = $featured_image = $view_more = '';

			$positions_str         = get_post_meta( $id, "position_member" );
			$url_array             = get_post_meta( $id, "social_url", true );
			$icon_array            = get_post_meta( $id, "icon_selection", true );
			$short_desc            = get_post_meta( $id, "member_short_desc", true );
			$wp_get_attachment_url = wp_get_attachment_url( get_post_thumbnail_id( $id ) );
			$post_cats             = wp_get_post_terms( $id, $this->TAXONOMY );
			$signature             = get_post_meta( $id, 'mb_signature' );
			if ( is_array( $signature ) && count( $signature ) ) {
				$signature = aq_resize( wp_get_attachment_url( $signature[0] ), "140", "50", false, true, true );
			}

			for ( $i = 0; $i < count( $post_cats ); $i ++ ) {
				$post_cat_term = $post_cats[ $i ];
				$post_cat_name = $post_cat_term->slug;
				$post_cats_str .= ' ' . $post_cat_name;
			}

			if ( isset( $url_array ) && ! empty( $url_array ) ) {
				for ( $i = 0; $i < count( $url_array ); $i ++ ) {
					$url             = $url_array[ $i ];
					$url_name        = esc_html( $url['name'] );
					$url_address     = $url['address'];
					$url_description = ! empty( $url['description'] ) ? esc_html( $url['description'] ) : '';
					if ( $single_member && ! empty( $url_address ) && ! empty( $url_description ) ) {
						$url_str .= '<div class="team_field">' . ( ! empty( $url_name ) ? '<h5>' . $url_name . ':</h5>' : '' ) . '<a href="' . esc_url( $url_address ) . '" class="team-link">' . $url_description . '</a></div>';
					} else if ( $single_member && ! empty( $url_address ) && empty( $url_description ) ) {
						$url_str .= '<div class="team_field">' . ( ! empty( $url_name ) ? '<h5>' . $url_name . ':</h5>' : '' ) . '<a href="' . esc_url( $url_address ) . '" class="team-link"><i class="fa fa-link"></i></a></div>';
					} else if ( $single_member && empty( $url_address ) && ! empty( $url_description ) ) {
						$url_str .= '<div class="team_field">' . ( ! empty( $url_name ) ? '<h5>' . $url_name . ':</h5>' : '' ) . '<div class="team_info-detail">' . $url_description . '</div></div>';
					}
				}
			}

			if ( isset( $icon_array ) && ! empty( $icon_array ) && (bool) array_filter( $icon_array[0] ) ) {
				$icon_str .= '<div class="team-icons">';
				for ( $i = 0; $i < count( $icon_array ); $i ++ ) {
					$icon         = $icon_array[ $i ];
					$icon_text    = ! empty( $icon['text'] ) ? esc_html( $icon['text'] ) : '';
					$icon_name    = ! empty( $icon['select'] ) ? esc_attr( $icon['select'] ) : '';
					$icon_address = ! empty( $icon['input'] ) ? esc_url( $icon['input'] ) : '#';
					$icon_color   = ! empty( $icon['color'] ) ? ' style="color: ' . esc_attr( $icon['color'] ) . '" ' : '';
					$icon_str     .= ! empty( $icon['select'] ) || ! empty( $icon['text'] )
						? '<a href="' . $icon_address . '" class="member-icon ' . $icon_name . '" ' . $icon_color . '><span>' . $icon_text . '</span></a>' : '';
				}
				$icon_str .= '</div>';
			}

			if ( strlen( $wp_get_attachment_url ) ) {

				switch ( $settings['posts_per_line'] ) {
					case "1":
						$gt3_featured_image_size = "1200";
						break;
					case "2":
						$gt3_featured_image_size = "1140";
						break;
					case "3":
						$gt3_featured_image_size = "740";
						break;
					case "4":
						$gt3_featured_image_size = "540";
						break;
					case "5":
						$gt3_featured_image_size = "380";
						break;
					default:
						$gt3_featured_image_size = "1200";
				}

				$img_ratio      = 1167 / 1140;
				$img_proportion = wp_kses_post( apply_filters( 'gt3/core/render/team/team_img_prop', $img_ratio ) );

				$gt3_featured_image_url = aq_resize( $wp_get_attachment_url, $gt3_featured_image_size, $gt3_featured_image_size * $img_proportion, true, true, true );
				$featured_image         = '<img  src="' . $gt3_featured_image_url . '" alt="' . get_the_title() . '" />';

				$image_id = get_post_thumbnail_id();

				if ( $settings ) {
					$image_src      = wp_get_attachment_image_src( $image_id, 'full' );
					$title          = get_the_title( $image_id );
					$featured_image = $this::get_img_url( $image_src, $settings, $title );
				}

				if ( $custom_item_height == 'yes' ) {
					$featured_image = '<span class="team_image_cover" style="background-image: url(' . $gt3_featured_image_url . ')"></span>';
				}
			}

			if ( ( ! empty( $settings['type'] ) && $settings['type'] == 'type3' ) && ( ! empty( $settings['type'] ) && $settings['link_post'] == 'yes' ) ) {
				$view_more = '<div class="team_link"><a href="' . get_permalink( $id ) . '">' . esc_html__( 'View More', 'juris' ) . '</a></div>';
			}

			if ( ! $single_member ) {
				$compile .= '<li class="item-team-member' . $post_cats_str . ( empty( $featured_image ) ? ' item-team--no_image' : '' ) . '">';
				$compile .= '<div class="item_wrapper">';
				$compile .= '<div class="item">';
				if ( ! empty( $featured_image ) ) {
					$compile .= '<div class="team_img featured_img">' . ( $link_post == 'yes' ? '<a href="' . get_permalink( $id ) . '">' . $featured_image . '</a>' : $featured_image ) . '</div>';
				}
				if ( ! empty( $icon_str ) && $settings['show_social'] == 'yes' ) {
					$compile .= '<div class="team_icons_wrapper"><div class="member-icons">' . $icon_str . '</div></div>';
				}
				$compile .= '<div class="team-infobox">';
				if ( $settings['show_title'] == 'yes' || $settings['show_position'] == 'yes' ) {
					$compile .= '<div class="team_title">';
					$compile .= '<div class="team_title_wrapper">';
					if ( $settings['show_title'] == 'yes' ) {
						$compile .= '<h3 class="team_title__text">' . ( $link_post == 'yes' ? '<a href="' . get_permalink( $id ) . '">' . get_the_title() . '</a>' : get_the_title() ) . '</h3>';
					}

					if ( ! empty( $positions_str[0] ) && $settings['show_position'] == 'yes' ) {
						$compile .= '<div class="team-positions">' . $positions_str[0] . '</div>';
					}

					$compile .= '</div>';
					$compile .= '</div>';
				}

				if ( ! empty( $short_desc ) && $settings['show_description'] == 'yes' ) {
					$compile .= '<div class="team_info"><div class="member-short-desc">' . $short_desc . '</div></div>';
				}

				if ( ! empty( $signature ) && ( $settings['show_position'] == 'yes' || $settings['show_description'] == 'yes' || $settings['show_title'] == 'yes' ) ) {
					$compile .= '<div class="team_signature"><img src="' . $signature . '" alt="' . get_the_title() . '" /></div>';
				}

				if ( ! empty( $url_array ) && is_array( $url_array ) && $settings['show_fields'] == 'yes' ) {
					$compile .= '<div class="gt3_single_team_info">';
					foreach ( $url_array as $url_array_item ) {
						$compile .= '<div class="gt3_single_team_info__item">';
						$compile .= ! empty( $url_array_item['name'] ) ? '<h4>' . esc_html( $url_array_item['name'] ) . '</h4>' : '';
						$compile .= ! empty( $url_array_item['address'] ) ? '<a href="' . esc_url( $url_array_item['address'] ) . '" target="_blank">' : '';
						$compile .= ! empty( $url_array_item['description'] ) ? '<span>' . $url_array_item['description'] . '</span>' : '';
						$compile .= ! empty( $url_array_item['address'] ) ? '</a>' : '';
						$compile .= '</div>';
					}
					$compile .= '</div>';
				}

				if ( ! empty( $view_more ) ) {
					$compile .= $view_more;
				}

				$compile .= '</div>';
				$compile .= '</div>';
				$compile .= '</div>';
				$compile .= '</li>';
			} else {

				$page_title_conditional = ( ( gt3_option( 'page_title_conditional' ) == '1' || gt3_option( 'page_title_conditional' ) == true ) ) ? 'yes' : 'no';

				if ( class_exists( 'RWMB_Loader' ) && get_queried_object_id() !== 0 ) {
					$mb_page_title_conditional = rwmb_meta( 'mb_page_title_conditional' );
					if ( $mb_page_title_conditional == 'yes' ) {
						$page_title_conditional = 'yes';
					} else if ( $mb_page_title_conditional == 'no' ) {
						$page_title_conditional = 'no';
					}
				}

				$compile .= '<div class="row single-member-page">
                <div class="span7">
                    <div class="team_img featured_img">
                        ' . $featured_image . '
                    </div>
                </div>
                <div class="span5">
                    <div class="team-infobox">'
				            . ( $page_title_conditional != 'yes' ? '<div class="team_title"><h3>' . get_the_title() . '</h3></div>' : '' ) .

				            '<div class="team_info">' .
				            ( ! empty( $url_str ) ? $url_str : '' ) .
				            ( ! empty( $icon_str ) ? '<div class="member-icons">' . $icon_str . '</div>' : '' ) .
				            '</div>
                    </div>
                </div>
            </div>';
			}

			$this->render_index ++;

			return $compile;
		}

		public function get_img_url( $image_src = false, $settings = false, $title = false ) {
			if ( $settings ) {

				$grid_type = 'square';
				$cols      = $settings['posts_per_line'];

				if ( ! empty( $image_src[0] ) && strlen( $image_src[0] ) ) {
					$wp_get_attachment_url = $image_src[0];
					if ( ! empty( $grid_type ) && $grid_type != 'vertical' ) {
						switch ( $grid_type ) {
							case 'square':
								$ration = 1;
								break;
							case 'rectangle':
								$ration = 0.8;
								break;
							default:
								$ration = null;
								break;
						}
					} else {
						$ration = null;
					}
					switch ( $cols ) {
						case '1':
							if ( function_exists( 'gt3_get_image_srcset' ) ) {
								$responsive_dimensions = array(
									array( '1200', '1600' ),
									array( '992', '1200' ),
									array( '768', '992' ),
									array( '600', '768' ),
									array( '420', '600' )
								);
								array_unshift( $responsive_dimensions, array( '1600', '1920' ) );
								$gt3_featured_image_url = gt3_get_image_srcset( $wp_get_attachment_url, $ration, $responsive_dimensions );
							} else {
								$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "1170", null, true, true, true ) . '"';
							}
							break;
						case '2':
							if ( function_exists( 'gt3_get_image_srcset' ) ) {
								$responsive_dimensions = array(
									array( '1200', '800' ),
									array( '992', '500' ),
									array( '768', '496' ),
									array( '600', '384' ),
									array( '420', '600' )
								);
								array_unshift( $responsive_dimensions, array( '1920', '1200' ), array(
									'1600',
									'960'
								) );
								$gt3_featured_image_url = gt3_get_image_srcset( $wp_get_attachment_url, $ration, $responsive_dimensions );
							} else {
								$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "570", "570", true, true, true ) . '"';
							}
							break;
						case '3':
							if ( function_exists( 'gt3_get_image_srcset' ) ) {
								$responsive_dimensions = array(
									array( '1200', '540' ),
									array( '992', '400' ),
									array( '768', '496' ),
									array( '600', '384' ),
									array( '420', '600' )
								);
								array_unshift( $responsive_dimensions, array( '2000', '1200' ), array(
									'1920',
									'670'
								), array( '1620', '640' ) );
								$gt3_featured_image_url = gt3_get_image_srcset( $wp_get_attachment_url, $ration, $responsive_dimensions );
							} else {
								$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "400", "400", true, true, true ) . '"';
							}
							break;
						case '4':
							if ( function_exists( 'gt3_get_image_srcset' ) ) {
								$responsive_dimensions = array(
									array( '1200', '400' ),
									array( '992', '300' ),
									array( '768', '496' ),
									array( '600', '384' ),
									array( '420', '600' )
								);
								array_unshift( $responsive_dimensions, array( '2000', '800' ), array(
									'1921',
									'500'
								), array( '1600', '480' ) );

								$gt3_featured_image_url = gt3_get_image_srcset( $wp_get_attachment_url, $ration, $responsive_dimensions );
							} else {
								$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "300", "300", true, true, true ) . '"';
							}
							break;

						case '5':
							if ( function_exists( 'gt3_get_image_srcset' ) ) {
								$responsive_dimensions = array(
									array( '1200', '300' ),
									array( '992', '300' ),
									array( '768', '496' ),
									array( '600', '384' ),
									array( '420', '600' )
								);
								array_unshift( $responsive_dimensions, array( '2000', '800' ), array(
									'1921',
									'500'
								), array( '1600', '480' ) );

								$ration = 1.565;

								$gt3_featured_image_url = gt3_get_image_srcset( $wp_get_attachment_url, $ration, $responsive_dimensions );
							} else {
								$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "300", "300", true, true, true ) . '"';
							}
							break;

						default:
							$gt3_featured_image_url = 'src="' . aq_resize( $wp_get_attachment_url, "1170", $ration, true, true, true ) . '"';
					}

					$featured_image = '<img ' . $gt3_featured_image_url . ( ! empty( $title ) ? ' title="' . esc_attr( $title ) . '"  alt="'.esc_attr( $title ).'"' : '' ) . ' />';

				} else {
					$featured_image = '';
				}

				return $featured_image;
			}

			return false;
		}
	}
}



